==> 0.1.0.tar.gz: android/src/main/kotlin/com/twtech/keyboard_languages/KeyboardLanguagesPlugin.kt <==
package com.twtech.keyboard_languages

import androidx.annotation.NonNull
import android.os.LocaleList
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result

/** KeyboardLanguagesPlugin */
class KeyboardLanguagesPlugin: FlutterPlugin, MethodCallHandler {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private lateinit var channel : MethodChannel

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(flutterPluginBinding.binaryMessenger, "keyboard_languages")
    channel.setMethodCallHandler(this)
  }

  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
    if (call.method == "getKeyboardLanguages") {
      val keyboardLanguages = mutableListOf<String>()
      var locales = LocaleList.getDefault();
      var numLocales = locales.size()
      while (numLocales > 0) {
        numLocales--
        var locale = locales.get(numLocales)
        keyboardLanguages.add(locale.toString())
      }
      result.success(keyboardLanguages)

    } else {
      result.notImplemented()
    }
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }
}

==> 0.1.3.tar.gz: android/src/main/kotlin/com/twtech/keyboard_languages/KeyboardLanguagesPlugin.kt <==
package com.twtech.keyboard_languages

import androidx.annotation.NonNull
import android.os.LocaleList
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result

/** KeyboardLanguagesPlugin */
class KeyboardLanguagesPlugin: FlutterPlugin, MethodCallHandler {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private lateinit var channel : MethodChannel

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(flutterPluginBinding.binaryMessenger, "keyboard_languages")
    channel.setMethodCallHandler(this)
  }

  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
    if (call.method == "getKeyboardLanguages") {
      val keyboardLanguages = mutableListOf<String>()
      var locales = LocaleList.getDefault();
      var numLocales = locales.size()
      while (numLocales > 0) {
        numLocales--
        var locale = locales.get(numLocales)
        keyboardLanguages.add(locale.toLanguageTag())
      }
      result.success(keyboardLanguages)

    } else {
      result.notImplemented()
    }
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }
}
